@@ -26,9 +26,10 @@ class PyXploraApi(PyXplora):
         userLang: str,
         timeZone: str,
         childPhoneNumber: list[str] = [],
-        wuid: any = None,
+        wuid: str | list = None,
+        email: str = None,
     ) -> None:
-        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber, wuid)
+        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber, wuid, email)
 
     async def _login(self, forceLogin: bool = False) -> dict[any, any]:
         if not self._isConnected() or self._hasTokenExpired() or forceLogin:
@@ -40,6 +41,7 @@ class PyXploraApi(PyXplora):
                     self._password,
                     self._userLang,
                     self._timeZone,
+                    self._email,
                 )
                 if self._gqlHandler:
                     retryCounter = 0
@@ -440,7 +442,7 @@ class PyXploraApi(PyXplora):
                 await sleep(self.retryDelay)
         return school_silent_mode
 
-    async def setEnableSilentTime(self, silentId: str, wuid: str) -> bool:
+    async def setEnableSilentTime(self, silentId: str) -> bool:
         retryCounter = 0
         dataOk = ""
         _raw = ""
@@ -460,7 +462,7 @@ class PyXploraApi(PyXplora):
                 await sleep(self.retryDelay)
         return bool(_raw)
 
-    async def setDisableSilentTime(self, silentId: str, wuid: str) -> bool:
+    async def setDisableSilentTime(self, silentId: str) -> bool:
         retryCounter = 0
         dataOk = ""
         _raw = ""
@@ -483,16 +485,16 @@ class PyXploraApi(PyXplora):
     async def setAllEnableSilentTime(self, wuid: str) -> list[bool]:
         res: list[bool] = []
         for silentTime in await self.getSilentTime(wuid):
-            res.append(await self.setEnableSilentTime(silentTime.get("id", ""), wuid))
+            res.append(await self.setEnableSilentTime(silentTime.get("id", "")))
         return res
 
     async def setAllDisableSilentTime(self, wuid: str) -> list[bool]:
         res: list[bool] = []
         for silentTime in await self.getSilentTime(wuid):
-            res.append(await self.setDisableSilentTime(silentTime.get("id", ""), wuid))
+            res.append(await self.setDisableSilentTime(silentTime.get("id", "")))
         return res
 
-    async def setEnableAlarmTime(self, alarmId: str, wuid: str) -> bool:
+    async def setEnableAlarmTime(self, alarmId: str) -> bool:
         retryCounter = 0
         dataOk = ""
         _raw = ""
@@ -512,7 +514,7 @@ class PyXploraApi(PyXplora):
                 await sleep(self.retryDelay)
         return bool(_raw)
 
-    async def setDisableAlarmTime(self, alarmId: str, wuid: str) -> bool:
+    async def setDisableAlarmTime(self, alarmId: str) -> bool:
         retryCounter = 0
         dataOk = ""
         _raw = ""
@@ -535,13 +537,13 @@ class PyXploraApi(PyXplora):
     async def setAllEnableAlarmTime(self, wuid: str) -> list[bool]:
         res: list[bool] = []
         for alarmTime in await self.getWatchAlarm(wuid):
-            res.append(await self.setEnableAlarmTime(alarmTime.get("id", ""), wuid))
+            res.append(await self.setEnableAlarmTime(alarmTime.get("id", "")))
         return res
 
     async def setAllDisableAlarmTime(self, wuid: str) -> list[bool]:
         res: list[bool] = []
         for alarmTime in await self.getWatchAlarm(wuid):
-            res.append(await self.setDisableAlarmTime(alarmTime.get("id", ""), wuid))
+            res.append(await self.setDisableAlarmTime(alarmTime.get("id", "")))
         return res
 
     async def sendText(self, text: str, wuid: str) -> bool:
